package Treex::EN;
{
  $Treex::EN::VERSION = '0.07191';
}
use strict;
use warnings;

1;

__END__

=pod

=encoding utf-8

=head1 NAME

Treex::EN - collection of blocks for processing English

=head1 VERSION

version 0.07191

=head1 SYNOPSIS

 use Treex::EN;

 #TODO

=head1 DESCRIPTION

=head1 AUTHOR

Tomáš Kraut <kraut@ufal.mff.cuni.cz>

=head1 COPYRIGHT AND LICENSE

Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague

This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
